Installing VirtualBox Image — OppiaMobile 0.5.2 documentation

# Installing VirtualBox Image

As well as the Amazon Web Services Machine Image, we also have a VirtualBox image of a new/clean installation of the OppiaMobile Server.

The latest version is available to download from: http://downloads.digital-campus.org/OppiaMobile/virtualbox-images/

The configuration is all set up with the same directory structure, passwords etc as on the AWS image, so you can find all the details here.

The only additional information you should need is the user login account:

- username: oppia
- password: default

Obviously as soon as you have installed the machine you should change this to something much more secure.

## Downloading the Virtual Machine Images

The VirtualBox images are large files (2Gb+) so may take a long time to download. To help those of you on slow connections, we have made the latest Virtual Machine Image available to download by using BitTorrent Sync (http://www.bittorrent.com/sync), using the read-only key `BI2VPY62BTBZ6K7C764KZCOAVDA2IJEET`.

## Environment information

The current version of the instance (OppiaMobile Server 0.4.3) is running:

- Ubuntu 14.04.1 LTS Desktop
- Apache 2.4
- Mysql 5.5
- Django 1.6.1
- TastyPie 0.11.0
- South 0.8.4
- OppiaServer 0.4.3